==> libstpk-0.9.4.0.tar.gz: libstpk-0.9.4.0/demo/simple_model/draw_cross.f90 <==
program draw
! Thorpe η̤Ǥդ 2 ܤαľ̤ 2 ̤βɲõҤ.
! ߤۤ Makefile ˤϵҤƤʤ.
! Ȥ draw Ʊ draw_Thorpe.nml ư褦ˤƤ.
! ڤľϥľ˻ꤷƤ.
  use dcl
  use Dcl_Automatic
  use gtool_history
  use Statistics
  use max_min
  use Thermo_Const
  use file_operate
  use basis

  implicit none

  integer :: i, j, k
  integer :: nx, ny, nl
  integer :: nargv, fig_type
  integer :: xdmin, xdmax, ydmin, ydmax
  real :: xmin, xmax, ymin, ymax, xscale, yscale
  real, allocatable, dimension(:) :: x, y
  real, allocatable, dimension(:,:) :: val1, val2, val3, val4, xd, yd, vald
  real, allocatable, dimension(:,:) :: ydd
  character(80) :: argv
  character(80) :: cont_val, shade_val, vx_val, vy_val, fname, txtname
  character(80) :: x_axis, y_axis
  character(80), allocatable, dimension(:,:) :: cval
  character(80) :: draw_title, title
  real :: cmin, cmax, smin, smax, sfact, cfact, vxfact, vyfact

  cont_val=''
  shade_val=''
  vx_val=''
  vy_val=''

  namelist /drawinput /fig_type, nx, ny, xmin, xmax, ymin, ymax, fname,  &
  &                    txtname, cont_val, shade_val, vx_val, vy_val,  &
  &                    cmin, cmax, smin, smax, x_axis, y_axis,  &
  &                    sfact, cfact, vxfact, vyfact, title
  read(5,nml=drawinput)

  allocate(x(nx))
  allocate(y(ny))
  allocate(val1(nx,ny))
  allocate(val2(nx,ny))
  allocate(val3(nx,ny))
  allocate(val4(nx,ny))
  allocate(vald(ny,2))
  allocate(ydd(ny,2))

  call SGISET('IFONT',2 )
  call UZFACT( 0.6 )
  call GLLSET('LMISS',.TRUE.)

  if(trim(title)=='')then
     draw_title=trim(cont_val)//' and '//trim(shade_val)
  else
     draw_title=trim(title)
  end if

!-- ѿ
  call HistoryGet( trim(fname), trim(x_axis), x(1:nx) )
  call HistoryGet( trim(fname), trim(y_axis), y(1:ny) )
  if(cont_val/='')then
     call HistoryGet( trim(fname), trim(cont_val), val1(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val1(i,j)/=999.0)then
              val1(i,j)=val1(i,j)*cfact
           end if
        end do
     end do
  end if
  if(shade_val/='')then
     call HistoryGet( trim(fname), trim(shade_val), val2(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val2(i,j)/=999.0)then
              val2(i,j)=val2(i,j)*sfact
           end if
        end do
     end do
  end if
  if(vx_val/='')then
     call HistoryGet( trim(fname), trim(vx_val), val3(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val3(i,j)/=999.0)then
              val3(i,j)=val3(i,j)
           end if
        end do
     end do
  end if
  if(vy_val/='')then
     call HistoryGet( trim(fname), trim(vy_val), val4(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val4(i,j)/=999.0)then
              val4(i,j)=val4(i,j)
           end if
        end do
     end do
  end if

!-- ƥȥǡ뤫ǧ
  if(txtname/='')then
     nl=line_number_counter( trim(txtname) )
     allocate(xd(nl,3))
     allocate(yd(nl,3))
     allocate(cval(2,nl))

     call read_file_text( trim(txtname), 2, nl, cval )

     do i=1,nl
        xd(i,1)=c2r_convert( cval(1,i) )
        yd(i,1)=c2r_convert( cval(2,i) )
     end do
  end if

!-- ΰη
  call nearest_search_1d( x, xmin, xdmin )
  call nearest_search_1d( x, xmax, xdmax )
  call nearest_search_1d( y, ymin, ydmin )
  call nearest_search_1d( y, ymax, ydmax )

  xscale=0.005
  call calc_vscale( (/(xmax-xmin), (ymax-ymin)/), (/0.6, 0.6/), xscale, yscale )
  yscale=yscale

  write(*,*) "cross sections are ", nx/10, nx/2, 'layers'
  xd(1:nl,2)=x(nx/10)
  yd(1,2)=y(ydmin)
  yd(2:nl,2)=y(ydmax)
  xd(1:nl,3)=x(nx/2)
  yd(1,3)=y(ydmin)
  yd(2:nl,3)=y(ydmax)

  do i=ydmin, ydmax
     vald(i,1)=val1(nx/10,i)
     vald(i,2)=val1(nx/2,i)
     ydd(i,1:2)=y(i)
  end do

!  dummy=-10.0
write(*,*) "draw", trim(draw_title)
  call color_setting( 10, (/smin, smax/), min_tab=999, max_tab=1999 )  

  call DclOpenGraphics(2)

  call Dcl_2D_cont_shade( trim(draw_title),  &
  &    x(xdmin:xdmax), y(ydmin:ydmax),  &
  &    val1(xdmin:xdmax,ydmin:ydmax),  &
  &    val2(xdmin:xdmax,ydmin:ydmax),  &
  &    (/cmin, cmax/), (/smin, smax/),  &
  &    (/trim(x_axis), trim(y_axis)/), (/'(f6.1)', 'f(6.1)'/),  &
  &    c_num=(/10, 10/), viewx_int=(/0.1, 0.7/), viewy_int=(/0.2, 0.8/),  &
  &    xg=xd(:,:), yg=yd(:,:), trigleg='a', no_tone=.true. )  !,  &

  call Dcl_PL( 'l', '',  &
  &            vald(ydmin:ydmax,1:2), ydd(ydmin:ydmax,1:2),  &
  &            vald(ydmin:ydmax,1:2), ydd(ydmin:ydmax,1:2),  &
  &            (/'', ''/), (/0.8, 0.95/), (/0.2, 0.8/),  &
  &            (/cmin, cmax/), (/y(ydmin), y(ydmax)/), no_frame=.true. )

  call DclCloseGraphics

end program

==> libstpk-0.9.31.0.tar.gz: libstpk-0.9.31.0/demo/simple_model/draw_cross.f90 <==
program draw
! Thorpe の結果から任意の 2 本の鉛直断面を 2 次元断面の横に追加記述する.
! 現在は陽に Makefile には記述していない.
! 使い方は draw と同じで draw_Thorpe.nml で動作するようにしてある.
! 切る鉛直軸はソース内で直に指定している.
  use dcl
  use Dcl_Automatic
  use gtool_history
  use Statistics
  use max_min
  use Thermo_Const
  use file_operate
  use basis

  implicit none

  integer :: i, j, k
  integer :: nx, ny, nl
  integer :: nargv, fig_type
  integer :: xdmin, xdmax, ydmin, ydmax
  real :: xmin, xmax, ymin, ymax, xscale, yscale
  real, allocatable, dimension(:) :: x, y
  real, allocatable, dimension(:,:) :: val1, val2, val3, val4, xd, yd, vald
  real, allocatable, dimension(:,:) :: ydd
  character(80) :: argv
  character(80) :: cont_val, shade_val, vx_val, vy_val, fname, txtname
  character(80) :: x_axis, y_axis
  character(80), allocatable, dimension(:,:) :: cval
  character(80) :: draw_title, title
  real :: cmin, cmax, smin, smax, sfact, cfact, vxfact, vyfact

  cont_val=''
  shade_val=''
  vx_val=''
  vy_val=''

  namelist /drawinput /fig_type, nx, ny, xmin, xmax, ymin, ymax, fname,  &
  &                    txtname, cont_val, shade_val, vx_val, vy_val,  &
  &                    cmin, cmax, smin, smax, x_axis, y_axis,  &
  &                    sfact, cfact, vxfact, vyfact, title
  read(5,nml=drawinput)

  allocate(x(nx))
  allocate(y(ny))
  allocate(val1(nx,ny))
  allocate(val2(nx,ny))
  allocate(val3(nx,ny))
  allocate(val4(nx,ny))
  allocate(vald(ny,2))
  allocate(ydd(ny,2))

  call SGISET('IFONT',2 )
  call UZFACT( 0.6 )
  call GLLSET('LMISS',.TRUE.)

  if(trim(title)=='')then
     draw_title=trim(cont_val)//' and '//trim(shade_val)
  else
     draw_title=trim(title)
  end if

!-- 変数入力
  call HistoryGet( trim(fname), trim(x_axis), x(1:nx) )
  call HistoryGet( trim(fname), trim(y_axis), y(1:ny) )
  if(cont_val/='')then
     call HistoryGet( trim(fname), trim(cont_val), val1(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val1(i,j)/=999.0)then
              val1(i,j)=val1(i,j)*cfact
           end if
        end do
     end do
  end if
  if(shade_val/='')then
     call HistoryGet( trim(fname), trim(shade_val), val2(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val2(i,j)/=999.0)then
              val2(i,j)=val2(i,j)*sfact
           end if
        end do
     end do
  end if
  if(vx_val/='')then
     call HistoryGet( trim(fname), trim(vx_val), val3(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val3(i,j)/=999.0)then
              val3(i,j)=val3(i,j)
           end if
        end do
     end do
  end if
  if(vy_val/='')then
     call HistoryGet( trim(fname), trim(vy_val), val4(1:nx,1:ny) )

     do j=1,ny
        do i=1,nx
           if(val4(i,j)/=999.0)then
              val4(i,j)=val4(i,j)
           end if
        end do
     end do
  end if

!-- テキストデータがあるか確認
  if(txtname/='')then
     nl=line_number_counter( trim(txtname) )
     allocate(xd(nl,3))
     allocate(yd(nl,3))
     allocate(cval(2,nl))

     call read_file_text( trim(txtname), 2, nl, cval )

     do i=1,nl
        xd(i,1)=c2r_convert( cval(1,i) )
        yd(i,1)=c2r_convert( cval(2,i) )
     end do
  end if

!-- 描画領域の決定
  call nearest_search_1d( x, xmin, xdmin )
  call nearest_search_1d( x, xmax, xdmax )
  call nearest_search_1d( y, ymin, ydmin )
  call nearest_search_1d( y, ymax, ydmax )

  xscale=0.005
  call calc_vscale( (/(xmax-xmin), (ymax-ymin)/), (/0.6, 0.6/), xscale, yscale )
  yscale=yscale

  write(*,*) "cross sections are ", nx/10, nx/2, 'layers'
  xd(1:nl,2)=x(nx/10)
  yd(1,2)=y(ydmin)
  yd(2:nl,2)=y(ydmax)
  xd(1:nl,3)=x(nx/2)
  yd(1,3)=y(ydmin)
  yd(2:nl,3)=y(ydmax)

  do i=ydmin, ydmax
     vald(i,1)=val1(nx/10,i)
     vald(i,2)=val1(nx/2,i)
     ydd(i,1:2)=y(i)
  end do

!  dummy=-10.0
write(*,*) "draw", trim(draw_title)
  call color_setting( 10, (/smin, smax/), min_tab=999, max_tab=1999 )  

  call DclOpenGraphics(2)

  call Dcl_2D_cont_shade( trim(draw_title),  &
  &    x(xdmin:xdmax), y(ydmin:ydmax),  &
  &    val1(xdmin:xdmax,ydmin:ydmax),  &
  &    val2(xdmin:xdmax,ydmin:ydmax),  &
  &    (/cmin, cmax/), (/smin, smax/),  &
  &    (/trim(x_axis), trim(y_axis)/), (/'(f6.1)', 'f(6.1)'/),  &
  &    c_num=(/10, 10/), viewx_int=(/0.1, 0.7/), viewy_int=(/0.2, 0.8/),  &
  &    xg=xd(:,:), yg=yd(:,:), trigleg='a', no_tone=.true. )  !,  &

  call Dcl_PL( 'l', '',  &
  &            vald(ydmin:ydmax,1:2), ydd(ydmin:ydmax,1:2),  &
  &            vald(ydmin:ydmax,1:2), ydd(ydmin:ydmax,1:2),  &
  &            (/'', ''/), (/0.8, 0.95/), (/0.2, 0.8/),  &
  &            (/cmin, cmax/), (/y(ydmin), y(ydmax)/), no_frame=.true. )

  call DclCloseGraphics

end program
